**ROTATE AWS KEYS**

As a security best practice, AWS recommends that users periodically regenerate their AWS access keys. This tool simplifies the rotation of access keys for any user. Before running, create text files and list the user names that have to be blacklisted and whitelisted respectively.